==> kubernetes-model-4.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestFluentImpl.java <==
package io.fabric8.kubernetes.api.model.certificates;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;

public class CertificateSigningRequestFluentImpl<A extends CertificateSigningRequestFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements CertificateSigningRequestFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private CertificateSigningRequestSpecBuilder spec;
    private CertificateSigningRequestStatusBuilder status;

    public CertificateSigningRequestFluentImpl(){
    }
    public CertificateSigningRequestFluentImpl(CertificateSigningRequest instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public CertificateSigningRequestFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public CertificateSigningRequestFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public CertificateSigningRequestFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public CertificateSigningRequestSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public CertificateSigningRequestSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(CertificateSigningRequestSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new CertificateSigningRequestSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public CertificateSigningRequestFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public CertificateSigningRequestFluent.SpecNested<A> withNewSpecLike(CertificateSigningRequestSpec item){
            return new SpecNestedImpl(item);
    }

    public CertificateSigningRequestFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public CertificateSigningRequestFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new CertificateSigningRequestSpecBuilder().build());
    }

    public CertificateSigningRequestFluent.SpecNested<A> editOrNewSpecLike(CertificateSigningRequestSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public CertificateSigningRequestStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public CertificateSigningRequestStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(CertificateSigningRequestStatus status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new CertificateSigningRequestStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public CertificateSigningRequestFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public CertificateSigningRequestFluent.StatusNested<A> withNewStatusLike(CertificateSigningRequestStatus item){
            return new StatusNestedImpl(item);
    }

    public CertificateSigningRequestFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public CertificateSigningRequestFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new CertificateSigningRequestStatusBuilder().build());
    }

    public CertificateSigningRequestFluent.StatusNested<A> editOrNewStatusLike(CertificateSigningRequestStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            CertificateSigningRequestFluentImpl that = (CertificateSigningRequestFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CertificateSigningRequestFluent.MetadataNested<N>> implements CertificateSigningRequestFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) CertificateSigningRequestFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends CertificateSigningRequestSpecFluentImpl<CertificateSigningRequestFluent.SpecNested<N>> implements CertificateSigningRequestFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final CertificateSigningRequestSpecBuilder builder;
    
            SpecNestedImpl(CertificateSigningRequestSpec item){
                    this.builder = new CertificateSigningRequestSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new CertificateSigningRequestSpecBuilder(this);
            }
    
    public N and(){
            return (N) CertificateSigningRequestFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends CertificateSigningRequestStatusFluentImpl<CertificateSigningRequestFluent.StatusNested<N>> implements CertificateSigningRequestFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final CertificateSigningRequestStatusBuilder builder;
    
            StatusNestedImpl(CertificateSigningRequestStatus item){
                    this.builder = new CertificateSigningRequestStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new CertificateSigningRequestStatusBuilder(this);
            }
    
    public N and(){
            return (N) CertificateSigningRequestFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> kubernetes-model-4.5.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestFluentImpl.java <==
package io.fabric8.kubernetes.api.model.certificates;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class CertificateSigningRequestFluentImpl<A extends CertificateSigningRequestFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements CertificateSigningRequestFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private CertificateSigningRequestSpecBuilder spec;
    private CertificateSigningRequestStatusBuilder status;

    public CertificateSigningRequestFluentImpl(){
    }
    public CertificateSigningRequestFluentImpl(CertificateSigningRequest instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public CertificateSigningRequestFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public CertificateSigningRequestFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public CertificateSigningRequestFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public CertificateSigningRequestFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public CertificateSigningRequestSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public CertificateSigningRequestSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(CertificateSigningRequestSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new CertificateSigningRequestSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public CertificateSigningRequestFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public CertificateSigningRequestFluent.SpecNested<A> withNewSpecLike(CertificateSigningRequestSpec item){
            return new SpecNestedImpl(item);
    }

    public CertificateSigningRequestFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public CertificateSigningRequestFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new CertificateSigningRequestSpecBuilder().build());
    }

    public CertificateSigningRequestFluent.SpecNested<A> editOrNewSpecLike(CertificateSigningRequestSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public CertificateSigningRequestStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public CertificateSigningRequestStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(CertificateSigningRequestStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new CertificateSigningRequestStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public CertificateSigningRequestFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public CertificateSigningRequestFluent.StatusNested<A> withNewStatusLike(CertificateSigningRequestStatus item){
            return new StatusNestedImpl(item);
    }

    public CertificateSigningRequestFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public CertificateSigningRequestFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new CertificateSigningRequestStatusBuilder().build());
    }

    public CertificateSigningRequestFluent.StatusNested<A> editOrNewStatusLike(CertificateSigningRequestStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            CertificateSigningRequestFluentImpl that = (CertificateSigningRequestFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CertificateSigningRequestFluent.MetadataNested<N>> implements CertificateSigningRequestFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) CertificateSigningRequestFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends CertificateSigningRequestSpecFluentImpl<CertificateSigningRequestFluent.SpecNested<N>> implements CertificateSigningRequestFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final CertificateSigningRequestSpecBuilder builder;
    
            SpecNestedImpl(CertificateSigningRequestSpec item){
                    this.builder = new CertificateSigningRequestSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new CertificateSigningRequestSpecBuilder(this);
            }
    
    public N and(){
            return (N) CertificateSigningRequestFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends CertificateSigningRequestStatusFluentImpl<CertificateSigningRequestFluent.StatusNested<N>> implements CertificateSigningRequestFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final CertificateSigningRequestStatusBuilder builder;
    
            StatusNestedImpl(CertificateSigningRequestStatus item){
                    this.builder = new CertificateSigningRequestStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new CertificateSigningRequestStatusBuilder(this);
            }
    
    public N and(){
            return (N) CertificateSigningRequestFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
